@@ -5,7 +5,7 @@ from tonplay.methods import TonPlayApi
 
 client = TonPlayApi(api_key=get_api_key())
 
-payout_id = str(uuid.uuid4())
+withdrawal_id = str(uuid.uuid4())
 print(
-    client.make_payout_request(payout_id)
+    client.make_withdraw_request(withdrawal_id)
 )
\ No newline at end of file
